Variables, Statements, and Expressions
::::::::::::::::::::::::::::::::::::::

.. toctree::
   :caption: Variables, Statements, and Expressions
   :maxdepth: 2

   intro-VariablesExpressionsandStatements.rst
   Values.rst
   Operators.rst
   FunctionCalls.rst
   DataTypes.rst
   ConvertTypeFunctions.rst
   Variables.rst
   VariableNamesandKeywords.rst
   WPChoosingtheRightVariableName.rst
   StatementsandExpressions.rst
   OrderofOperations.rst
   Reassignment.rst
   UpdatingVariables.rst
   HardCoding.rst
   Input.rst
   Glossary.rst
   Exercises.rst
   week1a2.rst
   